#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pep517']

package_data = \
{'': ['*']}

install_requires = \
['pytoml']

setup(name='pep517',
      version='0.2',
      description='Wrappers to build Python packages using PEP 517 hooks',
      author='Thomas Kluyver',
      author_email='thomas@kluyver.me.uk',
      url='https://github.com/takluyver/pep517',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
